@@ -28,13 +28,11 @@
 
 #include "config.h"
 
-#ifdef HAVE_DYNMANIFEST_H
-# include <lv2/lv2plug.in/ns/ext/dynmanifest/dynmanifest.h>
-#else
-# include <lv2/lv2plug.in/ns/ext/dyn-manifest/dyn-manifest.h>
-#endif
-#include <lv2/lv2plug.in/ns/ext/event/event.h>
-#include <lv2/lv2plug.in/ns/ext/uri-map/uri-map.h>
+#include "lv2/lv2plug.in/ns/ext/dynmanifest/dynmanifest.h"
+#include "lv2/lv2plug.in/ns/ext/atom/atom.h"
+#include "lv2/lv2plug.in/ns/ext/atom/util.h"
+#include "lv2/lv2plug.in/ns/ext/urid/urid.h"
+#include "lv2/lv2plug.in/ns/ext/midi/midi.h"
 
 #include "bridge.h"
 #include "pluglib.h"
