@@ -13,8 +13,6 @@
 /* libdssialsacompat has this one commented out */
 void snd_midi_event_init(snd_midi_event_t *dev);
 
-#define LV2_MIDI_URI "http://lv2plug.in/ns/ext/midi"
-
 /* Taken from ALSA */
 #define MAX_MIDI_EVENT_BUF	256
 
@@ -24,8 +22,8 @@ typedef struct
   {
 	LADSPA_Handle		 handle;
 	DSSI_Descriptor		*descriptor;
-	uint16_t		 ev_id_midi;
-	LV2_Event_Buffer	*ev_buf;
+	LV2_URID		 urid_midi;
+	LV2_Atom_Sequence	*atom_seq;
 	snd_midi_event_t	*alsa_ev_parser;
 	snd_seq_event_t		 alsa_ev_buf[MAX_MIDI_EVENTS];
   } instance_t;
@@ -36,7 +34,7 @@ instantiate(const LV2_Descriptor *descriptor, double sample_rate,
 {
 	instance_t *ret;
 	DSSI_Descriptor *ddesc;
-	LV2_URI_Map_Feature *um_feat;
+	LV2_URID_Map *map;
 	size_t i;
 
 	ddesc = nabrit_plugin_get_opaque(
@@ -48,23 +46,15 @@ instantiate(const LV2_Descriptor *descriptor, double sample_rate,
 
 	if (ddesc->run_synth != NULL)
 	  {
-		um_feat = NULL;
+		map = NULL;
 		for (i = 0; features[i] != NULL; i++)
 		  {
-			if (strcmp(features[i]->URI, LV2_URI_MAP_URI) == 0)
-				um_feat = features[i]->data;
+			if (strcmp(features[i]->URI, LV2_URID__map) == 0)
+				map = features[i]->data;
 		  }
 
-		if (um_feat == NULL)
-		  {
-			free(ret);
-			return NULL;
-		  }
-
-		ret->ev_id_midi = um_feat->uri_to_id(um_feat->callback_data,
-						     LV2_EVENT_URI,
-						     LV2_MIDI_URI "#MidiEvent");
-		if (ret->ev_id_midi == 0)
+		ret->urid_midi = map->map(map->handle, LV2_MIDI__MidiEvent);
+		if (ret->urid_midi == 0)
 		  {
 			free(ret);
 			return NULL;
@@ -109,7 +99,7 @@ connect_port(LV2_Handle instance, uint32_t port, void *data_location)
 	i = (instance_t *)instance;
 
 	if (port == i->descriptor->LADSPA_Plugin->PortCount)
-		i->ev_buf = (LV2_Event_Buffer *)data_location;
+		i->atom_seq = (LV2_Atom_Sequence *)data_location;
 	else
 		i->descriptor->LADSPA_Plugin->connect_port(i->handle, port,
 							   data_location);
@@ -190,33 +180,23 @@ run_synth(LV2_Handle instance, uint32_t sample_count)
 	instance_t *i;
 	snd_seq_event_t *alsa_ev;
 	snd_seq_event_t alsa_tmp_ev;
-	LV2_Event *ev;
-	unsigned char *p, *data;
+	unsigned char *data;
 	unsigned long count;
-	size_t j;
 
 	i = (instance_t *)instance;
 
 	/* Convert MIDI events to ALSA Sequencer events */
-	p = i->ev_buf->data;
-	alsa_ev  = i->alsa_ev_buf;
+	alsa_ev = i->alsa_ev_buf;
 	count = 0;
-	for (j = 0; (j < i->ev_buf->event_count)
-		    && ((alsa_ev - i->alsa_ev_buf) < MAX_MIDI_EVENTS); j++)
+	LV2_ATOM_SEQUENCE_FOREACH(i->atom_seq, ev)
 	  {
-		ev = (LV2_Event *)p;
-		p += sizeof(LV2_Event);
-		data = p;
-		p += ev->size;
-		if (((ev->size + sizeof(LV2_Event)) % 8) != 0)
-			p += 8 - (sizeof(LV2_Event) + ev->size) % 8;
-
-		/* Let's pretend ev->type is never 0... LV2 Events bug? */
-		if (ev->type != i->ev_id_midi)
+		if (ev->body.type != i->urid_midi)
 			continue;
 
-		if (snd_midi_event_encode(i->alsa_ev_parser, data, ev->size,
-					  &alsa_tmp_ev) < 0)
+		data = LV2_ATOM_BODY(&ev->body);
+
+		if (snd_midi_event_encode(i->alsa_ev_parser, data,
+					  ev->body.size, &alsa_tmp_ev) < 0)
 		  {
 			snd_midi_event_reset_encode(i->alsa_ev_parser);
 			continue;
@@ -226,7 +206,7 @@ run_synth(LV2_Handle instance, uint32_t sample_count)
 		    || (alsa_tmp_ev.type == SND_SEQ_EVENT_PGMCHANGE))
 			continue;
 
-		alsa_tmp_ev.time.tick = ev->frames;
+		alsa_tmp_ev.time.tick = ev->time.frames;
 		*alsa_ev = alsa_tmp_ev;
 
 		alsa_ev++;
