@@ -26,11 +26,7 @@
 
 #include "config.h"
 
-#ifdef HAVE_DYNMANIFEST_H
-# include <lv2/lv2plug.in/ns/ext/dynmanifest/dynmanifest.h>
-#else
-# include <lv2/lv2plug.in/ns/ext/dyn-manifest/dyn-manifest.h>
-#endif
+#include "lv2/lv2plug.in/ns/ext/dynmanifest/dynmanifest.h"
 
 #include "bridge.h"
 #include "pluglib.h"
